@@ -1,3 +1,3 @@
 # Author:码思客-木森
 # WeChart:musen9111
-from .manage import run, run_test
+from .manage import run
